
# Pocsuite

[![Python 2.6|2.7](https://img.shields.io/badge/python-2.6|2.7-yellow.svg)](https://www.python.org/) [![License](https://img.shields.io/badge/license-GPLv2-red.svg)](https://raw.githubusercontent.com/knownsec/Pocsuite/master/docs/COPYING) [![Twitter](https://img.shields.io/badge/twitter-@seebug-blue.svg)](https://twitter.com/seebug_team) [![build](https://api.travis-ci.org/knownsec/Pocsuite.svg)](https://travis-ci.org/knownsec/Pocsuite)



## Overview

Pocsuite is an open-sourced remote vulnerability testing and proof-of-concept development framework developed by the [**Knownsec Security Team**](http://www.knownsec.com/). It comes with a powerful proof-of-concept engine, many niche features for the ultimate penetration testers and security researchers.

## How to use

### Pocsuite with seebug PoC search and zoomeye dork
[![asciicast](https://asciinema.org/a/133345.png)](https://asciinema.org/a/133345)

### Pocsuite with seebug PoC and zoomeye dork
[![asciicast](https://asciinema.org/a/133344.png)](https://asciinema.org/a/133344)

### Pocsuite with zoomeye API

[![asciicast](https://asciinema.org/a/133343.png)](https://asciinema.org/a/133343)

### Pocsuite with seebug PoC API online
[![asciicast](https://asciinema.org/a/133342.png)](https://asciinema.org/a/133342)

## Requirements

- Python 2.6+
- Works on Linux, Windows, Mac OSX, BSD

## Installation

The quick way:

``` bash
$ pip install pocsuite
```

Or click [here](https://github.com/knownsec/Pocsuite/archive/master.zip) to download the latest source zip package and extract

``` bash
$ wget https://github.com/knownsec/Pocsuite/archive/master.zip
$ unzip master.zip
```


The latest version of this software is available from: http://pocsuite.org

## Documentation

Documentation is available in the [```english docs```](./docs)  / [```chinese docs```](./docs/translations/) directory.
## How to Contribute

1. Check for open issues or open a fresh issue to start a discussion around a feature idea or a bug.
2. Fork [the repository](https://github.com/knownsec/Pocsuite) on GitHub to start making your changes to the **dev** branch (or branch off of it).
3. Write a test which shows that the bug was fixed or that the feature works as expected.
4. Send a pull request and bug the maintainer until it gets merged and published. Make sure to add yourself to [THANKS](./docs/THANKS.md).


## Links

* [Thanks List](./docs/THANKS.md)
* [Change Log](./docs/CHANGELOG.md)
* [Bug tracking](https://github.com/knownsec/Pocsuite/issues)
* [Copyright](./docs/COPYING)
* [Pocsuite](http://pocsuite.org)
* [Seebug](https://www.seebug.org)
* [ZoomEye](https://www.zoomeye.org)
